@@ -1,4 +1,4 @@
-__version__ = "2.41.0"
+__version__ = "2.43.1"
 
 from .rapidata_client import (
     RapidataClient,
@@ -17,6 +17,7 @@ from .rapidata_client import (
     FreeTextMinimumCharacters,
     NoShuffle,
     PlayVideoUntilTheEnd,
+    MuteVideo,
     CustomSetting,
     AllowNeitherBoth,
     SwapContextInstruction,
@@ -31,11 +32,6 @@ from .rapidata_client import (
     AgeGroup,
     GenderFilter,
     Gender,
-    CountryCodes,
-    MediaAsset,
-    TextAsset,
-    MultiAsset,
-    RapidataDataTypes,
     Box,
     Datapoint,
     PromptMetadata,
