@@ -1,29 +1,26 @@
-from typing import Any
 from rapidata.rapidata_client.filter._base_filter import RapidataFilter
 from rapidata.api_client.models.age_user_filter_model import AgeUserFilterModel
 from rapidata.rapidata_client.filter.models.age_group import AgeGroup
+from pydantic import BaseModel, ConfigDict
 
 
-class AgeFilter(RapidataFilter):
+class AgeFilter(RapidataFilter, BaseModel):
     """AgeFilter Class
 
     Can be used to filter who to target based on age groups.
 
-
     Args:
         age_groups (list[AgeGroup]): List of age groups to filter by."""
 
+    model_config = ConfigDict(arbitrary_types_allowed=True)
+
+    age_groups: list[AgeGroup]
+
     def __init__(self, age_groups: list[AgeGroup]):
-        self.age_groups = age_groups
+        super().__init__(age_groups=age_groups)
 
     def _to_model(self):
         return AgeUserFilterModel(
             _t="AgeFilter",
             ageGroups=[age_group._to_backend_model() for age_group in self.age_groups],
         )
-
-    def __str__(self) -> str:
-        return f"AgeFilter(age_groups={self.age_groups})"
-
-    def __repr__(self) -> str:
-        return f"AgeFilter(age_groups={self.age_groups!r})"
