@@ -4,9 +4,10 @@ from rapidata.api_client.models.not_user_filter_model import NotUserFilterModel
 from rapidata.api_client.models.and_user_filter_model_filters_inner import (
     AndUserFilterModelFiltersInner,
 )
+from pydantic import BaseModel, ConfigDict
 
 
-class NotFilter(RapidataFilter):
+class NotFilter(RapidataFilter, BaseModel):
     """A filter that negates another filter's condition.
     This class implements a logical NOT operation on a given filter, inverting its results.
 
@@ -23,20 +24,15 @@ class NotFilter(RapidataFilter):
         This will limit the order to be shown to only people who have their phone set to a language other than English.
     """
 
-    def __init__(self, filter: RapidataFilter):
-        if not isinstance(filter, RapidataFilter):
-            raise ValueError("Filter must be a RapidataFilter object")
+    model_config = ConfigDict(arbitrary_types_allowed=True)
 
-        self.filter = filter
+    filter: RapidataFilter
+
+    def __init__(self, filter: RapidataFilter):
+        super().__init__(filter=filter)
 
     def _to_model(self):
         return NotUserFilterModel(
             _t="NotFilter",
             filter=AndUserFilterModelFiltersInner(self.filter._to_model()),
         )
-
-    def __str__(self) -> str:
-        return f"NotFilter(filter={self.filter})"
-
-    def __repr__(self) -> str:
-        return f"NotFilter(filter={self.filter!r})"
