@@ -1,4 +1,4 @@
-from typing import Literal, Optional, Sequence
+from typing import Literal, Optional, Sequence, get_args
 import random
 import urllib.parse
 import webbrowser
@@ -20,7 +20,6 @@ from rapidata.api_client.models.sticky_state import StickyState
 from rapidata.rapidata_client.datapoints._datapoint import Datapoint
 from rapidata.rapidata_client.exceptions.failed_upload_exception import (
     FailedUploadException,
-    _parse_failed_uploads,
 )
 from rapidata.rapidata_client.filter import RapidataFilter
 from rapidata.rapidata_client.config import (
@@ -38,12 +37,18 @@ from rapidata.rapidata_client.referee import Referee
 from rapidata.rapidata_client.referee._naive_referee import NaiveReferee
 from rapidata.rapidata_client.selection._base_selection import RapidataSelection
 from rapidata.rapidata_client.settings import RapidataSetting
-from rapidata.rapidata_client.workflow import Workflow, FreeTextWorkflow
+from rapidata.rapidata_client.workflow import (
+    Workflow,
+    FreeTextWorkflow,
+    MultiRankingWorkflow,
+)
 from rapidata.service.openapi_service import OpenAPIService
 from rapidata.rapidata_client.api.rapidata_api_client import (
     suppress_rapidata_error_logging,
 )
 
+StickyStateLiteral = Literal["Temporary", "Permanent", "Passive"]
+
 
 class RapidataOrderBuilder:
     """Builder object for creating Rapidata orders.
@@ -62,7 +67,7 @@ class RapidataOrderBuilder:
     ):
         self._name = name
         self.order_id: str | None = None
-        self.__openapi_service = openapi_service
+        self._openapi_service = openapi_service
         self.__dataset: Optional[RapidataDataset] = None
         self.__workflow: Workflow | None = None
         self.__referee: Referee | None = None
@@ -72,11 +77,9 @@ class RapidataOrderBuilder:
         self.__selections: list[RapidataSelection] = []
         self.__priority: int | None = None
         self.__datapoints: list[Datapoint] = []
-        self.__sticky_state_value: Literal["None", "Temporary", "Permanent"] | None = (
-            None
-        )
+        self.__sticky_state_value: StickyStateLiteral | None = None
         self.__validation_set_manager: ValidationSetManager = ValidationSetManager(
-            self.__openapi_service
+            self._openapi_service
         )
 
     def _to_model(self) -> CreateOrderModel:
@@ -145,9 +148,10 @@ class RapidataOrderBuilder:
             with suppress_rapidata_error_logging():
                 self.__validation_set_id = (
                     (
-                        self.__openapi_service.validation_api.validation_set_recommended_get(
+                        self._openapi_service.validation_api.validation_set_recommended_get(
                             asset_type=[self.__datapoints[0].get_asset_type()],
                             modality=[self.__workflow.modality],
+                            instruction=self.__workflow._get_instruction(),
                             prompt_type=[
                                 t.value for t in self.__datapoints[0].get_prompt_type()
                             ],
@@ -203,8 +207,12 @@ class RapidataOrderBuilder:
         Returns:
             RapidataOrder: The created RapidataOrder instance.
         """
-        if rapidata_config.order.autoValidationSetCreation and not isinstance(
-            self.__workflow, FreeTextWorkflow
+        if (
+            rapidata_config.order.autoValidationSetCreation
+            and not isinstance(
+                self.__workflow, (FreeTextWorkflow, MultiRankingWorkflow)
+            )
+            and not self.__selections
         ):
             new_validation_set = self._set_validation_set_id()
         else:
@@ -213,7 +221,7 @@ class RapidataOrderBuilder:
         order_model = self._to_model()
         logger.debug("Creating order with model: %s", order_model)
 
-        result = self.__openapi_service.order_api.order_post(
+        result = self._openapi_service.order_api.order_post(
             create_order_model=order_model
         )
 
@@ -228,7 +236,7 @@ class RapidataOrderBuilder:
                 + f"A new validation set was created. Please annotate {required_amount} datapoint{('s' if required_amount != 1 else '')} so the order runs correctly."
                 + Fore.RESET
             )
-            link = f"https://app.{self.__openapi_service.environment}/validation-set/detail/{self.__validation_set_id}/annotate?orderId={self.order_id}&required={required_amount}"
+            link = f"https://app.{self._openapi_service.environment}/validation-set/detail/{self.__validation_set_id}/annotate?orderId={self.order_id}&required={required_amount}"
             could_open_browser = webbrowser.open(link)
             if not could_open_browser:
                 encoded_url = urllib.parse.quote(link, safe="%/:=&?~#+!$,;'@()*[]")
@@ -243,7 +251,7 @@ class RapidataOrderBuilder:
             managed_print()
 
         self.__dataset = (
-            RapidataDataset(result.dataset_id, self.__openapi_service)
+            RapidataDataset(result.dataset_id, self._openapi_service)
             if result.dataset_id
             else None
         )
@@ -254,7 +262,7 @@ class RapidataOrderBuilder:
 
         order = RapidataOrder(
             order_id=self.order_id,
-            openapi_service=self.__openapi_service,
+            openapi_service=self._openapi_service,
             name=self._name,
         )
 
@@ -276,17 +284,8 @@ class RapidataOrderBuilder:
         logger.debug("Datapoints added to the order.")
         logger.debug("Setting order to preview")
         try:
-            self.__openapi_service.order_api.order_order_id_preview_post(self.order_id)
+            self._openapi_service.order_api.order_order_id_preview_post(self.order_id)
         except Exception:
-            failed_uploads = _parse_failed_uploads(
-                self.__openapi_service.dataset_api.dataset_dataset_id_datapoints_failed_get(
-                    self.__dataset.id
-                )
-            )
-            logger.error(
-                "Internal download error for datapoints: %s\nWARNING: Failed Datapoints in error do not contain metadata.",
-                failed_uploads,
-            )
             raise FailedUploadException(self.__dataset, order, failed_uploads)
         return order
 
@@ -461,18 +460,16 @@ class RapidataOrderBuilder:
         return self
 
     def _sticky_state(
-        self, sticky_state: Literal["None", "Temporary", "Permanent"] | None = None
+        self, sticky_state: StickyStateLiteral | None = None
     ) -> "RapidataOrderBuilder":
         """
         Set the sticky state for the order.
         """
-        if sticky_state is not None and sticky_state not in [
-            "None",
-            "Temporary",
-            "Permanent",
-        ]:
-            raise TypeError(
-                "Sticky state must be of type Literal['None', 'Temporary', 'Permanent']."
+        sticky_state_valid_values = get_args(StickyStateLiteral)
+
+        if sticky_state is not None and sticky_state not in sticky_state_valid_values:
+            raise ValueError(
+                f"Sticky state must be one of {sticky_state_valid_values} or None"
             )
 
         self.__sticky_state_value = sticky_state
