@@ -1,7 +1,7 @@
 from rapidata.rapidata_client.config.logger import logger
 from rapidata.rapidata_client.selection._base_selection import RapidataSelection
-from rapidata.api_client.models.conditional_validation_rapid_selection_config import (
-    ValidationChance,
+from rapidata.api_client.models.conditional_validation_selection_validation_chance import (
+    ConditionalValidationSelectionValidationChance,
 )
 from rapidata.api_client.models.conditional_validation_selection import (
     ConditionalValidationSelection as ConditionalValidationSelectionModel,
@@ -63,7 +63,7 @@ class ConditionalValidationSelection(RapidataSelection):
             _t="ConditionalValidationSelection",
             validationSetId=self.validation_set_id,
             validationChances=[
-                ValidationChance(
+                ConditionalValidationSelectionValidationChance(
                     userScoreThreshold=threshold, chance=chance, rapidCount=rapid_count
                 )
                 for threshold, chance, rapid_count in zip(
@@ -72,3 +72,9 @@ class ConditionalValidationSelection(RapidataSelection):
             ],
             dimensions=self.dimensions,
         )
+
+    def __str__(self) -> str:
+        return f"ConditionalValidationSelection(validation_set_id={self.validation_set_id}, thresholds={self.thresholds}, chances={self.chances}, rapid_counts={self.rapid_counts}, dimensions={self.dimensions})"
+
+    def __repr__(self) -> str:
+        return self.__str__()
