@@ -47,7 +47,7 @@ class ValidationSetManager:
 
     def __init__(self, openapi_service: OpenAPIService) -> None:
         self.__openapi_service = openapi_service
-        self.rapid = RapidsManager()
+        self.rapid = RapidsManager(openapi_service)
         logger.debug("ValidationSetManager initialized")
 
     def _create_order_validation_set(
@@ -61,12 +61,14 @@ class ValidationSetManager:
             "ValidationSetManager._create_order_validation_set"
         ):
             rapids: list[Rapid] = []
-            for datapoint in datapoints:
+            for datapoint in workflow._format_datapoints(datapoints):
                 rapids.append(
                     Rapid(
                         asset=datapoint.asset,
                         payload=workflow._to_payload(datapoint),
-                        metadata=datapoint.metadata,
+                        context=datapoint.context,
+                        media_context=datapoint.media_context,
+                        data_type=datapoint.data_type,
                         settings=settings,
                     )
                 )
@@ -143,11 +145,6 @@ class ValidationSetManager:
             logger.debug("Creating classification rapids")
             rapids: list[Rapid] = []
             for i in range(len(datapoints)):
-                rapid_metadata = []
-                if contexts:
-                    rapid_metadata.append(PromptMetadata(contexts[i]))
-                if media_contexts:
-                    rapid_metadata.append(MediaAssetMetadata(media_contexts[i]))
                 rapids.append(
                     self.rapid.classification_rapid(
                         instruction=instruction,
@@ -155,7 +152,10 @@ class ValidationSetManager:
                         datapoint=datapoints[i],
                         truths=truths[i],
                         data_type=data_type,
-                        metadata=rapid_metadata,
+                        context=contexts[i] if contexts != None else None,
+                        media_context=(
+                            media_contexts[i] if media_contexts != None else None
+                        ),
                         explanation=explanations[i] if explanations != None else None,
                     )
                 )
@@ -231,18 +231,16 @@ class ValidationSetManager:
             logger.debug("Creating comparison rapids")
             rapids: list[Rapid] = []
             for i in range(len(datapoints)):
-                rapid_metadata = []
-                if contexts:
-                    rapid_metadata.append(PromptMetadata(contexts[i]))
-                if media_contexts:
-                    rapid_metadata.append(MediaAssetMetadata(media_contexts[i]))
                 rapids.append(
                     self.rapid.compare_rapid(
                         instruction=instruction,
                         truth=truths[i],
                         datapoint=datapoints[i],
                         data_type=data_type,
-                        metadata=rapid_metadata,
+                        context=contexts[i] if contexts != None else None,
+                        media_context=(
+                            media_contexts[i] if media_contexts != None else None
+                        ),
                         explanation=explanation[i] if explanation != None else None,
                     )
                 )
@@ -387,17 +385,15 @@ class ValidationSetManager:
             rapids = []
             rapids: list[Rapid] = []
             for i in range(len(datapoints)):
-                rapid_metadata = []
-                if contexts:
-                    rapid_metadata.append(PromptMetadata(contexts[i]))
-                if media_contexts:
-                    rapid_metadata.append(MediaAssetMetadata(media_contexts[i]))
                 rapids.append(
                     self.rapid.locate_rapid(
                         instruction=instruction,
                         truths=truths[i],
                         datapoint=datapoints[i],
-                        metadata=rapid_metadata,
+                        context=contexts[i] if contexts != None else None,
+                        media_context=(
+                            media_contexts[i] if media_contexts != None else None
+                        ),
                         explanation=explanation[i] if explanation != None else None,
                     )
                 )
@@ -466,17 +462,15 @@ class ValidationSetManager:
             logger.debug("Creating draw rapids")
             rapids: list[Rapid] = []
             for i in range(len(datapoints)):
-                rapid_metadata = []
-                if contexts:
-                    rapid_metadata.append(PromptMetadata(contexts[i]))
-                if media_contexts:
-                    rapid_metadata.append(MediaAssetMetadata(media_contexts[i]))
                 rapids.append(
                     self.rapid.draw_rapid(
                         instruction=instruction,
                         truths=truths[i],
                         datapoint=datapoints[i],
-                        metadata=rapid_metadata,
+                        context=contexts[i] if contexts != None else None,
+                        media_context=(
+                            media_contexts[i] if media_contexts != None else None
+                        ),
                         explanation=explanation[i] if explanation != None else None,
                     )
                 )
@@ -546,17 +540,15 @@ class ValidationSetManager:
             logger.debug("Creating timestamp rapids")
             rapids: list[Rapid] = []
             for i in range(len(datapoints)):
-                rapid_metadata = []
-                if contexts:
-                    rapid_metadata.append(PromptMetadata(contexts[i]))
-                if media_contexts:
-                    rapid_metadata.append(MediaAssetMetadata(media_contexts[i]))
                 rapids.append(
                     self.rapid.timestamp_rapid(
                         instruction=instruction,
                         truths=truths[i],
                         datapoint=datapoints[i],
-                        metadata=rapid_metadata,
+                        context=contexts[i] if contexts != None else None,
+                        media_context=(
+                            media_contexts[i] if media_contexts != None else None
+                        ),
                         explanation=explanation[i] if explanation != None else None,
                     )
                 )
@@ -587,7 +579,7 @@ class ValidationSetManager:
         self,
         name: str,
         rapids: list[Rapid],
-        dimensions: list[str] | None,
+        dimensions: list[str],
     ) -> RapidataValidationSet:
         logger.debug("Creating validation set")
         validation_set_id = (
@@ -611,16 +603,27 @@ class ValidationSetManager:
         with tracer.start_as_current_span("Adding rapids to validation set"):
             logger.debug("Adding rapids to validation set")
             failed_rapids = []
-            for rapid in tqdm(
-                rapids,
+
+            progress_bar = tqdm(
+                total=len(rapids),
                 desc="Uploading validation tasks",
                 disable=rapidata_config.logging.silent_mode,
-            ):
+            )
+
+            for rapid in rapids:
                 try:
                     validation_set.add_rapid(rapid)
-                except Exception:
+                    progress_bar.update(1)
+                except Exception as e:
+                    logger.error(
+                        "Failed to add rapid %s to validation set.\nError: %s",
+                        rapid.asset,
+                        str(e),
+                    )
                     failed_rapids.append(rapid.asset)
 
+            progress_bar.close()
+
             if failed_rapids:
                 logger.error(
                     "Failed to add %s datapoints to validation set: %s",
@@ -669,13 +672,13 @@ class ValidationSetManager:
             )
 
     def find_validation_sets(
-        self, name: str = "", amount: int = 1
+        self, name: str = "", amount: int = 10
     ) -> list[RapidataValidationSet]:
         """Find validation sets by name.
 
         Args:
             name (str, optional): The name to search for. Defaults to "" to match with any set.
-            amount (int, optional): The amount of validation sets to return. Defaults to 1.
+            amount (int, optional): The amount of validation sets to return. Defaults to 10.
 
         Returns:
             list[RapidataValidationSet]: The list of validation sets.
@@ -709,3 +712,9 @@ class ValidationSetManager:
                 for validation_set in validation_page_result.items
             ]
             return validation_sets
+
+    def __str__(self) -> str:
+        return "ValidationSetManager"
+
+    def __repr__(self) -> str:
+        return self.__str__()
