@@ -10,6 +10,7 @@ from rapidata.rapidata_client.workflow import Workflow
 from rapidata.api_client import ClassifyPayload
 from rapidata.rapidata_client.datapoints._datapoint import Datapoint
 from rapidata.api_client.models.rapid_modality import RapidModality
+from rapidata.api_client.models.classify_payload_category import ClassifyPayloadCategory
 
 
 class ClassifyWorkflow(Workflow):
@@ -35,6 +36,9 @@ class ClassifyWorkflow(Workflow):
         self._instruction = instruction
         self._answer_options = answer_options
 
+    def _get_instruction(self) -> str:
+        return self._instruction
+
     def _to_dict(self) -> dict[str, Any]:
         return {
             **super()._to_dict(),
@@ -60,7 +64,10 @@ class ClassifyWorkflow(Workflow):
     def _to_payload(self, datapoint: Datapoint) -> ClassifyPayload:
         return ClassifyPayload(
             _t="ClassifyPayload",
-            possibleCategories=self._answer_options,
+            categories=[
+                ClassifyPayloadCategory(label=option, value=option)
+                for option in self._answer_options
+            ],
             title=self._instruction,
         )
 
