@@ -16,11 +16,15 @@ class LocateWorkflow(Workflow):
         super().__init__(type="SimpleWorkflowConfig")
         self._target = target
 
+    def _get_instruction(self) -> str:
+        return self._target
+
     def _to_model(self) -> SimpleWorkflowModel:
         blueprint = LocateRapidBlueprint(_t="LocateBlueprint", target=self._target)
 
         return SimpleWorkflowModel(
-            _t="SimpleWorkflow", blueprint=SimpleWorkflowModelBlueprint(blueprint)
+            _t="SimpleWorkflow",
+            blueprint=SimpleWorkflowModelBlueprint(blueprint),
         )
 
     def _to_payload(self, datapoint: Datapoint) -> LocatePayload:
